### -*- coding: utf-8 -*- ####################################################

import random

from django.db import models
from django.utils.translation import ugettext_lazy as _

from sorl.thumbnail.fields import ImageField 

from .utils import default_upload_to

class Banner(models.Model):

    slug = models.SlugField(_("Unique identifier"), unique=True)
    image = ImageField(_(u"Banner's image"), max_length=255, upload_to=default_upload_to, blank=True)
    link = models.CharField(_("External link"), max_length=255, blank=True, null=True)
    
    class Meta:
        ordering = ('slug',)
        verbose_name = _("banner")
        verbose_name_plural = _("banners")
    
    def __unicode__(self):
        return u"Banner: %s" % self.slug
    
    def get_image(self):
        """Returns random image using alternatives"""
        images = []
        if self.image:
            images.append(self.image)
        
        images.extend([i.image for i in self.alternatives.all()])
        
        return random.choice(images) if images else ''

class AlternativeImage(models.Model):
    
    banner = models.ForeignKey(Banner, verbose_name=_("banner"), related_name="alternatives")
    
    image = ImageField(_("image"), upload_to=default_upload_to)
    
    class Meta:
        verbose_name = _("alternative image")
        verbose_name_plural = _("alternative images")



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding model 'Banner'
        db.create_table('banner_banner', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('slug', self.gf('django.db.models.fields.SlugField')(unique=True, max_length=50, db_index=True)),
            ('image', self.gf('sorl.thumbnail.fields.ImageField')(default='images/default.jpg', max_length=100)),
            ('link', self.gf('django.db.models.fields.URLField')(max_length=200, null=True, blank=True)),
        ))
        db.send_create_signal('banner', ['Banner'])


    def backwards(self, orm):
        
        # Deleting model 'Banner'
        db.delete_table('banner_banner')


    models = {
        'banner.banner': {
            'Meta': {'ordering': "('slug',)", 'object_name': 'Banner'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('sorl.thumbnail.fields.ImageField', [], {'default': "'images/default.jpg'", 'max_length': '100'}),
            'link': ('django.db.models.fields.URLField', [], {'max_length': '200', 'null': 'True', 'blank': 'True'}),
            'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '50', 'db_index': 'True'})
        }
    }

    complete_apps = ['banner']



### -*- coding: utf-8 -*- ####################################################


from django.contrib import admin

from sorl.thumbnail.admin import AdminImageMixin

from .models import Banner, AlternativeImage

class AlternativeInline(AdminImageMixin, admin.TabularInline):
    model = AlternativeImage
    extra = 0

class BannerAdmin(AdminImageMixin, admin.ModelAdmin):

    list_display = ('slug', 'link')
    search_fields = ('slug', 'link')
    inlines = (AlternativeInline,)

admin.site.register(Banner, BannerAdmin)



### -*- coding: utf-8 -*- ####################################################

from django.conf import settings
from native_tags.decorators import function

from ..models import Banner

def get_banner(slug, width, height, queryset=Banner.objects.all()):
    banner = queryset.get_or_create(slug=slug.encode('utf-8'))[0]
    return "banner_source.html", {
                'banner': banner, 'size': "%ix%i" % (width, height), 
                'width': width, 'height': height, 
                'STATIC_URL': settings.STATIC_URL,
    }

get_banner = function(get_banner, inclusion=True, cache=60)



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Changing field 'Banner.image'
        db.alter_column('banner_banner', 'image', self.gf('sorl.thumbnail.fields.ImageField')(max_length=255))


    def backwards(self, orm):
        
        # Changing field 'Banner.image'
        db.alter_column('banner_banner', 'image', self.gf('sorl.thumbnail.fields.ImageField')(max_length=100))


    models = {
        'banner.banner': {
            'Meta': {'ordering': "('slug',)", 'object_name': 'Banner'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('sorl.thumbnail.fields.ImageField', [], {'max_length': '255', 'blank': 'True'}),
            'link': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '50', 'db_index': 'True'})
        }
    }

    complete_apps = ['banner']



### -*- coding: utf-8 -*- ####################################################

from django.contrib.contenttypes.models import ContentType

def default_upload_to(instance, file_name):
    app_label, model = ContentType.objects.get_for_model(instance).natural_key()
    return 'uploads/%s/%s/%s_%s' % (app_label, model, instance.pk or '0', file_name)



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding model 'AlternativeImage'
        db.create_table('banner_alternativeimage', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('banner', self.gf('django.db.models.fields.related.ForeignKey')(related_name='alternatives', to=orm['banner.Banner'])),
            ('image', self.gf('sorl.thumbnail.fields.ImageField')(max_length=100)),
        ))
        db.send_create_signal('banner', ['AlternativeImage'])


    def backwards(self, orm):
        
        # Deleting model 'AlternativeImage'
        db.delete_table('banner_alternativeimage')


    models = {
        'banner.alternativeimage': {
            'Meta': {'object_name': 'AlternativeImage'},
            'banner': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'alternatives'", 'to': "orm['banner.Banner']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('sorl.thumbnail.fields.ImageField', [], {'max_length': '100'})
        },
        'banner.banner': {
            'Meta': {'ordering': "('slug',)", 'object_name': 'Banner'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('sorl.thumbnail.fields.ImageField', [], {'max_length': '255', 'blank': 'True'}),
            'link': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '50', 'db_index': 'True'})
        }
    }

    complete_apps = ['banner']



### -*- coding: utf-8 -*- ####################################################
"""
Configuration file used by setuptools. It creates 'egg', install all dependencies.
"""

import os
from setuptools import setup, find_packages

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

#Dependencies - python eggs
install_requires = [
        'setuptools',
        'Django',
        'django-native-tags',
        'sorl-thumbnail >= 10.12',
]

#Execute function to handle setuptools functionality
setup(name="django-banner-simple",
    version="0.1",
    description="Simple banner system",
    long_description=read('README.rst'),
    packages=find_packages('src'),
    package_dir={'': 'src'},
    include_package_data=True,
    zip_safe=True,
    install_requires=install_requires,
    author='Arpaso',
    author_email='arvid@arpaso.com',
    url='https://github.com/Arpaso/django-banner-simple',
    download_url='https://github.com/Arpaso/django-banner-simple/tarball/0.1',
    classifiers=(
        "Framework :: Django",
        "Intended Audience :: Developers",
        "Intended Audience :: System Administrators",
        "Operating System :: OS Independent",
        "Topic :: Software Development",
    ),
)
